function [Met] = EmSite_Calc_Met_Thornthwaite(Emission_year,ipath)
global makeplot
%**************************************************************************
% Potential Evapotranspiration


%https://en.wikipedia.org/wiki/Potential_evaporation
yearday = datenum([Emission_year, 1 1 0 0 0]):1:datenum([Emission_year+1, 1 1 0 0 0]);
dt = datevec(yearday);

fprintf('Finding gridded Potential Evapotranspiration\n')
fprintf('Following Thorntwaite (1948) for year   %i \n',Emission_year)

ncfile   = sprintf('%sMET/TG_%04i.nc',ipath,Emission_year);
tpr      = ncread(ncfile,'tg');
fprintf('Monthly mean Temperature (Celsius) \n')
for month = 1:12
    idx = dt(:,2) == month;
    mT(:,:,month) =  mean(tpr(:,:,idx),3);
end
% Heat Index
mT(mT<0)=0;
tI = (mT/5).^1.514;
I = sum(tI,3);
alpha = (6.75*1e-7)*I.^3 -(7.71*1e-5)*I.^2 + (1.792*1e-2)*I+0.49239;
% length of day (sunlight hours)
L = [6, 8, 9, 12, 14, 16, 15, 14, 13, 12, 9, 6];

% length of month (days)
N = [31,28,31,30,31,30,31,31,30,31,30,31];
for month = 1:12
    idx = dt(:,2) == month;
    tPET(idx) =  16 *(L(month)/12)*(N(month)/30);
end
for i=1:length(tPET)
    dt = tpr(:,:,i);
    dt(dt<0)=0;
    PET(:,:,i) = (10*dt./I).^alpha;
end
Met.PET = PET;

if makeplot
    I(I==0)=NaN;
    fname = sprintf('Thornthwaithe_visual_%i',Emission_year);
    f = figure(1);
    subplot(3,2,[1,3])
    im = imagesc(I');
    title('Thorntwhaite Heat index')
    %set(im, 'AlphaData', ~isnan(I))
    colorbar
    set(gca,'XTickLabel','','YTickLabel','')
    
    subplot(3,2,[2,4])
    im = imagesc(squeeze(sum(PET,3))');
    title(sprintf('Annual Potential Evapotranspiration (mm) %i \n Thornthwaithe (1948)',Emission_year))
    %set(im, 'AlphaData', ~isnan(I))
    colorbar
    set(gca,'XTickLabel','','YTickLabel','')
    
    subplot(3,2,[5,6])
    plot(yearday,squeeze(nanmean(nanmean(PET))))
    datetick('x','mmm-yyyy','keepticks')
    title(sprintf('Daily Potential Evapotranspiration (mm) %i',Emission_year))
    saveas(f,fname,'png')
    fprintf('saved: %s\n',fname)
    
%     Ix = -20:.1:35
%     alpha = (6.75*1e-7)*Ix.^3 -(7.71*1e-5)*Ix.^2 + (1.792*1e-2)*Ix+0.49239;
    
end


end






