function [SDEMO] =  EmSite_DEMOLITION()
global ipath tpath opname ofilename
global outgridsize numPartsSSBOutFile
global printsplit Emission_year BuildDemo 
global HDDfile VariableVacation_file Phase_duration
global Anleggsdiesel_weight Tools_wight Heating_wight
global Tloes Tgc Tsilt LargeMachines_kWhm2 SmallMachines_kWhm2 
global EF_TSP EF_PM10 EF_PM25 SSBgridFile comps Fuelsplit_Large Fuelsplit_Small Fuelsplit_Heat Fuelsplit_Name
global typer Str EF_L_yr EF_S_yr EF_H_yr EF_G_yr EF_P_yr KMNEfilename

%--------------------------------------------------------------------------
% A N N U A L   D A T A   D E M  O L I T I O N
%--------------------------------------------------------------------------
fprintf(printsplit)
fprintf('A N N U A L   D A T A   D E M O L I T I O N \n')
fprintf(printsplit)
if ~contains(BuildDemo,{'DEMO'})
    fprintf('Not Doing Demolition files\n')
    fprintf(printsplit)
    SDEMO = [];
    return
end

file = strcat(ofilename,sprintf('%04i%s.xlsx',Emission_year,BuildDemo));
fprintf('reading file:  %s\n',file)
TdY  = readtable(file);

%--------------------------------------------------------------------------
% G R O U  N D   C O N D I T I O N S   A N D   S I L T   C O N T E N T
%--------------------------------------------------------------------------
fprintf('G R O U  N D   C O N D I T I O N S   A N D   S I L T   C O N T E N T \n')
fprintf(printsplit)

% ONCE jordart is defined in terms of use and final value, can be moved to
% preprocessing:
jordart    = TdY.Jordart;
GC         = zeros(size(jordart));
silt       = zeros(size(jordart));
for i = 1:height(Tloes)
    idx       = find(jordart == Tloes.jordart(i));
    GC(idx)   = Tgc.ID_GC(Tgc.ID_GC==Tloes.ID_GC(i));
    silt(idx) = Tsilt.SiltContent___(Tsilt.ID_Silt==Tloes.ID_Silt(i));
end
GC(GC>1) = 1;
TdY.GC   = GC;
TdY.Silt = silt;

%--------------------------------------------------------------------------
% T I M E   V A R I A T I O N
%--------------------------------------------------------------------------
fprintf('\nT I M E   V A R I A T I O N \n\n')
fprintf(printsplit)

Sin       = table2struct(TdY);
[TV,Sout] = EmSite_Station_Timevariation(Sin,HDDfile,VariableVacation_file,Emission_year);

%**************************************************************************
%--------------------------------------------------------------------------
% B U I L D I N G   P H A S E S   C O N S T R U C T I O N
%--------------------------------------------------------------------------
fprintf('D E M O L I T I O N  \n')
fprintf('B U I L D I N G   P H A S E S\n\n')
fprintf(printsplit)
% The following sections deal with all construction sites in the data read:

% Find the number of phases in the building process
machineEnd   = TdY.DEMOmachineEnd;
machineStart = TdY.DEMOmachineStart;
BRA          = TdY.BruksarealTotatl;
machineTime  = machineEnd-machineStart;


% Calculate monthly activity for each machine type on each buildsite
fprintf('   Calculating monthly activity \n')
fprintf(printsplit)
noti = 1000;
for b = 1:length(Sout)
    clear DA_HM DA_SM DA_HT
    Stmp = Sout(b);
    dateS = [extractfield(Sout(b),'DEMOmachineStart'),extractfield(Sout(b),'DEMOmachineEnd')];
    days  = extractfield(Sout(b),'DEMOmachineStart'):1:extractfield(Sout(b),'DEMOmachineEnd');
    for d = 2:length(dateS)
        idx1 = days >= dateS(d-1);
        idx2 = days <= dateS(d);
        idx = idx1 & idx2;
        DA_HM(idx) = 1;
        DA_SM(idx) = 1;
        DA_HT(idx) = 1;
    end
    % Normalize and multiply with m2  to get
    DA_HM = max(10,Stmp.BruksarealTotatl)* DA_HM/sum(DA_HM);
    DA_SM = max(10,Stmp.BruksarealTotatl)* DA_SM/sum(DA_SM);
    DA_HT = max(10,Stmp.BruksarealTotatl)* DA_HT/sum(DA_HT);
    
    % Define an activity for each month of the year for each machine type.
    for month = 1:12
        ps  = datenum([Emission_year, month,   1, 0 0 0]);
        pe  = datenum([Emission_year, month+1, 1, 0 0 0]);
        idx = (days>=ps & days<pe);
        
        HMw(b,month) = sum(DA_HM(idx));
        SMw(b,month) = sum(DA_SM(idx));
        HTw(b,month) = sum(DA_HT(idx));
    end
    if rem(b,noti)==0; fprintf('.'); if rem(b,10*noti)==0; fprintf('\n'); end; end
end
fprintf('\n')
save(sprintf('%s%i_MonthActivity_m2.mat',opname,Emission_year),'HMw','SMw','HTw')

%--------------------------------------------------------------------------
% F U E L   R E L A T E D   P A R A M E T E R I Z A T I O N S
%--------------------------------------------------------------------------
fprintf(printsplit)
fprintf('F U E L   D E M A N D  \n\n')
% ENERGY DEMAND Anleggsdiesel
E            = GC*LargeMachines_kWhm2;               % KWh LargeMachines_kWhm2
% ENERGY DEMAND Small machines

ES            = ones(size(Sout))*SmallMachines_kWhm2*0; % KWh SmallMachines_kWhm2
for month = 1:12
    HME(:,month)  = HMw(:,month).*E;
    SME(:,month)  = SMw(:,month).*ES;
end
%--------------------------------------------------------------------------
% HEATING DEGREE ADJUSTMENT TO HEATING DEMAND
%--------------------------------------------------------------------------
fprintf(printsplit)
%--------------------------------------------------------------------------
% N O N    E X H A U S T   D U S T   E M I S S I O N S
%--------------------------------------------------------------------------
fprintf('N O N    E X H A U S T   D U S T   E M I S S I O N S  \n\n')
fprintf(printsplit)
drying_factor = 0.8; % HEG parameterization factors
daily_runoff  = 0.9; % HEG parameterization factors
CE    = zeros(length(Sout),1); % CE         : CONTROL MEASURES (unitless)


MetgridXY(:,1) = TdY.MetX;
MetgridXY(:,2) = TdY.MetY;
Sout     = table2struct(TdY);



% Calculate using EMEP annual emissions
% METidx = zeros(length(Sout),1); % PE IN EMEP : EVAPOTRANSPIRATION
% EF emission factor in g/(m^2 yr)
% d  duration (year)
% BRA : Usable area (m²)
% silt in %

fprintf('E M E P   A N N U A L   E M I S S I O N S  \n\n')
fprintf(printsplit)

% Monthly resolution can use th index directly:
[Met] = EmSite_Calc_Met_Thornthwaite_index(Emission_year,ipath);
PEindex = Met.PEindex;
for b = 1:length(Sout)
    % find the time in that year there is construction
    st_yr    = max(datenum([Emission_year,1,1,0,0,0])   , Sout(b).DEMOmachineStart);
    en_yr    = min(datenum([Emission_year+1,1,1,0,0,0]) , Sout(b).DEMOmachineEnd);
    le_yr(b) = max(0,(en_yr-st_yr)/365);
    
    if le_yr(b)>0
        if isnan(MetgridXY(b,1)) || isnan(MetgridXY(b,1))
        METidx(b) = PEindex(1,120);            
        else
        METidx(b) = PEindex(MetgridXY(b,1),MetgridXY(b,2));
        %fprintf('.')
        METidx(b) = min([METidx(b),120]);
        % needs to be replacedby an actual test
        end
        
        type_Cons = typer.type_Cons(typer.Bygningstypekode== Sout(b).Bygningtypekode);
        
        if type_Cons <2
            bld_type = 1;
            bld_wgt  = 1;
        elseif type_Cons ==2
            bld_type = 2;
            bld_wgt  = 1.5;
        else
            bld_type = 3;
            bld_wgt  = 1.5;
        end
        D(b) = Sout(b).DEMOtidD/365 * le_yr(b);
        
        if METidx(b)<= 0; METidx(b)=1; end
        EMpm25(b)  = EF_PM25(bld_type) * D(b) *Sout(b).BruksarealTotatl*bld_wgt *(1-CE(b)) * (24/METidx(b)) *(Sout(b).Silt/0.09);
        EMpm10(b)  = EF_PM10(bld_type) * D(b) *Sout(b).BruksarealTotatl*bld_wgt *(1-CE(b)) * (24/METidx(b)) *(Sout(b).Silt/0.09);
        EM_TSP(b)  = EF_TSP(bld_type)  * D(b) *Sout(b).BruksarealTotatl*bld_wgt *(1-CE(b)) * (24/METidx(b)) *(Sout(b).Silt/0.09);
    else
        EMpm25(b) = 0;
        EMpm10(b) = 0;
        EM_TSP(b) = 0;
        % fprintf('%i le_yr %4.3f %i\n',b,le_yr(b),Sout(b).CONSTtidD)
    end
    % fprintf('%s\n',datestr(datenum([Emission_year,1,1,0,0,0]) ))
end

% -< CUT??
% if no precipitation in the building period, this goes to Inf.
% this should be dealt with now CHECK
EMpm25(EMpm25 > 1e8)  = -1;
EMpm10(EMpm10 > 1e9)  = -1;
EM_TSP(EM_TSP > 1e11) = -1;
k                     = find(EMpm25<0);

official_SSB2018      = [0.08*1e3, 0.76*1e3, 2.5*1e3]; % tonn
posit                 = EMpm25>0;
NORpm25 = nansum(EMpm25(posit))*1e-6;
NORpm10 = nansum(EMpm10(posit))*1e-6;
NOR_TSP = nansum(EM_TSP(posit))*1e-6;
fprintf('Total non-exhaust emissions %i \n',Emission_year)
fprintf('Total non-exhaust %6.2f ton PM2.5  \n',NORpm25)
fprintf('Total non-exhaust %6.2f ton PM10   \n',NORpm10)
fprintf('Total non-exhaust %6.2f ton PM TSP \n',NOR_TSP)
% >

%--------------------------------------------------------------------------
% G R I D D I N G   T H E   D A T A   O N T O   t h e   S S B   G R I D
%--------------------------------------------------------------------------
%--------------------------------------------------------------------------
% METOD 2 : IRREGULAR POLYGON TO GRID
% Make the building a polygon based on the Influence radius of each site
fprintf('\nMETOD 2 : IRREGULAR POLYGON TO GRID\n')
fprintf('METHOD USING ALL THE GRIDS COVERED BY THE INFLUENCE RADIUS\n\n')
Spoly       = Sout;
INFL_rad    = max(10,sqrt(BRA));
xc          = extractfield(Sout,'X');
yc          = extractfield(Sout,'Y');
for b = 1:length(Sout)
    % xc =Sout(b).X;
    Spoly(b).Geometry = 'Polygon';
    Spoly(b).X        =  [xc(b)-INFL_rad(b),xc(b)+INFL_rad(b),xc(b)+INFL_rad(b),xc(b)-INFL_rad(b),xc(b)-INFL_rad(b),NaN];
    Spoly(b).Y        =  [yc(b)-INFL_rad(b),yc(b)-INFL_rad(b),yc(b)+INFL_rad(b),yc(b)+INFL_rad(b),yc(b)-INFL_rad(b),NaN];
end
fprintf('Made irregular building squares\n')
dbf         = makedbfspec(Spoly);
polygonfile = sprintf('%s%i_%s_Polygons',opname,Emission_year,BuildDemo);

shapewrite(Spoly,polygonfile,'DbfSpec',dbf)
try; system(sprintf('cp %s.prj %s.prj',SSBgridFile,polygonfile)); end
fprintf('Wrote: %s \n',polygonfile)


noti = 1000;
for part = 1:numPartsSSBOutFile
    if numPartsSSBOutFile == 1
        SSBreadFile = SSBgridFile;
    else
        fprintf('Reading partitioned file, part %02i\n',part)
        SSBreadFile = strcat(SSBgridFile,sprintf('_%i',part));
        Sssb        = shaperead(SSBreadFile);
    end
    
    
    fprintf('Calculating CENTERPOINT (X,Y) for radius \n')
    xc_ssb = zeros(size(Sssb));
    yc_ssb = zeros(size(Sssb));
    noti   = 20000;
    for i= 1:length(Sssb)
        xc_ssb(i)      = nanmean(extractfield(Sssb(i),'X'));
        yc_ssb(i)      = nanmean(extractfield(Sssb(i),'Y'));
        if rem(i,noti)==0; fprintf('.'); if rem(i,10*noti)==0; fprintf('%i / %i \n',i,length(Sssb)); end; end
    end
    
    fprintf('Transfer from Irregular to Regular SSB GRID \n')
    SSB_H     = zeros(size(Sssb));
    SSB_S     = zeros(size(Sssb));
    SSB_T     = zeros(size(Sssb));
    SSB_PM25  = zeros(size(Sssb));
    SSB_PM10  = zeros(size(Sssb));
    SSB_TSP   = zeros(size(Sssb));
    
    noti   = 1000;
    Sunass = [];
    for b = 1:length(Spoly)% 200%
        dst     = sqrt((nanmean(Spoly(b).X)-xc_ssb).^2 +(nanmean(Spoly(b).Y)-yc_ssb).^2);
        lookfor = find(dst < 700);
        if ~(isempty(lookfor))
            ps = polyshape(Spoly(b).X,Spoly(b).Y);
            pa = polyarea(ps.Vertices(:,1),ps.Vertices(:,2));
            
            gSSB = Sssb(lookfor);
            
            tets = 0;
            for gi = 1:length(gSSB)
                p_ssb    = polyshape(gSSB(gi).X,gSSB(gi).Y);
                [Dx, Dy] = polybool('intersection',ps.Vertices(:,1),ps.Vertices(:,2),p_ssb.Vertices(:,1),p_ssb.Vertices(:,2));
                if ~isempty(Dx)>0
                    % IT IS HERE I CAN CHOOSE TO MAKE MONTHLY EMISSIONS BY
                    % CHANGING THE sum()
                    over = polyarea(Dx, Dy);
                    SSB_H(lookfor(gi)) = SSB_H(lookfor(gi))+ sum(HME(b,:))*(over/pa);
                    SSB_S(lookfor(gi)) = SSB_S(lookfor(gi))+ sum(SME(b,:))*(over/pa);
                    %SSB_T(lookfor(gi)) = SSB_T(lookfor(gi))+ sum(HTE(b,:))*(over/pa);
                    % ADDED HERE ANNUAL NON-EXHAUST (remove Inf!!!!!)
                    SSB_PM25(lookfor(gi)) = SSB_PM25(lookfor(gi)) + sum(EMpm25(:,b))*(over/pa);
                    SSB_PM10(lookfor(gi)) = SSB_PM10(lookfor(gi)) + sum(EMpm10(:,b))*(over/pa);
                    SSB_TSP(lookfor(gi))  = SSB_TSP(lookfor(gi))  + sum(EM_TSP(:,b))*(over/pa);
                    tets = tets+(over/pa);
                end
            end
             % fprintf('%d\n',tets)
        else % collect the unassigned construction projects for further looking into
             % Sunass = [Sunass;Spoly(b)];
        end
        if rem(b,noti)==0; fprintf('.'); if rem(b,10*noti)==0; fprintf('%i / %i \n',b,length(Spoly)); end; end
    end
    
    % To speed up the process cosider::  Spoly = Sunass;
    fprintf('\n')
    fname      = sprintf('%s%i_%s_SSB%i_IPM2_p%02i',tpath,Emission_year,BuildDemo,outgridsize,part);
    a1         = SSB_H>0;b1 = SSB_S>0;% c1 = SSB_T>0;
    hasSSB     = a1|b1;%|c1;
    SssbU      = Sssb(hasSSB);
    Tbssb      = struct2table(SssbU);
    Tbssb.HNRM = SSB_H(hasSSB);
    Tbssb.SNRM = SSB_S(hasSSB);
    Tbssb.HEAT(:) = 0;
    
    Tbssb.PM25ne = SSB_PM25(hasSSB);
    Tbssb.PM10ne = SSB_PM10(hasSSB);
    Tbssb.TSPne  = SSB_TSP(hasSSB);
    
    Stmp       = table2struct(Tbssb);
    
    Large_kW = extractfield(Stmp,'HNRM');
    Small_kW = extractfield(Stmp,'SNRM');
    % Heat_kW  = extractfield(Stmp,'HEAT');
    
    EM   = zeros(size(Large_kW,2),size(comps,2));
    EM_L = zeros(size(EM));
    EM_S = zeros(size(EM));
    EM_H = zeros(size(EM));
    Fuel = zeros(size(Large_kW,2),size(Fuelsplit_Name,2));
    
    for c =1 :length(comps)
        idxL = find(ismember(EF_L_yr.Properties.VariableNames,comps(c)));
        EFL  = table2array(EF_L_yr(1,idxL));
        
        idxS = find(ismember(EF_S_yr.Properties.VariableNames,comps(c)));
        EFS  = table2array(EF_S_yr(1,idxS));
        
        % idxH = find(ismember(EF_H_yr.Properties.VariableNames,comps(c)));
        % EFH  = table2array(EF_H_yr(1,idxH));
        
        idxG = find(ismember(EF_G_yr.Properties.VariableNames,comps(c)));
        EFG  = table2array(EF_G_yr(1,idxG));
        
        idxP = find(ismember(EF_P_yr.Properties.VariableNames,comps(c)));
        EFP  = table2array(EF_P_yr(1,idxG));
        
        if ismember(comps(c),{'FC'})
            Fuel(:,1) = EFL*Large_kW*Fuelsplit_Large(1)+ EFS*Small_kW *Fuelsplit_Small(1); %  + EFH * Heat_kW  *Fuelsplit_Heat(1);
            Fuel(:,2) = EFP*Small_kW *Fuelsplit_Small(2);
            Fuel(:,3) = 0; % EFG*Heat_kW *Fuelsplit_Heat(3);
        else
            EM_L(:,c) = EFL * Large_kW * Fuelsplit_Large(1);
            EM_S(:,c) = EFS * Small_kW * Fuelsplit_Small(1)+ EFP*Small_kW *Fuelsplit_Small(2);
            EM_H(:,c) = 0; %EFH * Heat_kW  * Fuelsplit_Heat(1) + EFG * Heat_kW * Fuelsplit_Heat(3);
            EM(:,c)   = EM_L(:,c) +  EM_S(:,c) + EM_H(:,c);
        end
    end
    
    TEM = array2table(EM);
    TEM.Properties.VariableNames = comps;
    TEM = TEM(:,~ismember(TEM.Properties.VariableNames,{'FC'}));
    
    Tfuel = array2table(Fuel);
    Tfuel.Properties.VariableNames = Fuelsplit_Name;
    Tmp      = [Tbssb,Tfuel,TEM];
    Stmp     = table2struct(Tmp);
    
    [Stmp] = EmSite_Geoprocess_Add_Municipality_SSBgrid(KMNEfilename,Stmp);
   
   % [Stmp] = EmSite_SSBgridKommune(Stmp);

    
    dbf        = makedbfspec(Stmp);
    shapewrite(Stmp,fname,'DbfSpec',dbf)
    fprintf('Wrote file %s\n',fname)
    try; system(sprintf('cp %s.prj %s.prj',SSBreadFile,fname)); end
end

% Finally, if necessary, make a combined output file
if numPartsSSBOutFile > 1
    fprintf('Combine the partial SSB files to a National\n')
    Sgrid = [];
    for part = 1:numPartsSSBOutFile
        fname    = sprintf('%s%i_%s_SSB%i_IPM2_p%02i',tpath,Emission_year,BuildDemo,outgridsize,part);
        Spolyp   = shaperead(fname);
        Sgrid   = [Sgrid;Spolyp];
    end
%     % add municipality to SSB grid 
%     filename = sprintf('%s%s',ipath,'KMN/Kommuner2020');
%     [Sgrid] = EmSite_Geoprocess_Add_Municipality_SSBgrid(filename,Sgrid);

    ofname    = sprintf('%s%i_%s_SSB%i_IPM2',opname,Emission_year,BuildDemo,outgridsize);
    dbf = makedbfspec(Sgrid);
    shapewrite(Sgrid,ofname,'DbfSpec',dbf)
    fprintf('Wrote file %s\n',ofname)
    try; system(sprintf('cp %s.prj %s.prj',SSBgridFile,ofname)); end
else
    Sgrid = Stmp;
end

SDEMO = Sgrid;
end