function [TB,Sout] = EmSite_Geoprocess_KV_ActiveBuilds(filename,f,fylkenr,Str)

late          = datenum([2055,1,1,0,0,0]);
early         = datenum([0,1,1,0,0,0])-1;
maxDEMOTime   = 5000;
meanDEMOtime  =  230;
maxCONSTime   = 5000;
meanCONSTtime =  550;



T = readtable(filename,'HeaderLines',3);
T.Geometry(:) = {'Point'};
idx = find(ismember(T.Properties.VariableNames,'x_st'));
T.Properties.VariableNames(idx) = {'X'};
idx = find(ismember(T.Properties.VariableNames,'Nord'));
T.Properties.VariableNames(idx) = {'Y'};
idx = find(ismember(T.Properties.VariableNames,'Var10'));
T.Properties.VariableNames(idx) = {'Bygningstatusendring'};
if ~isnumeric(T.Bygningtypekode)
    T.Bygningtypekode = str2num(char(T.Bygningtypekode));
end
T.Action(:) = 0;

% find the unique number of buildings that have change history in the
% period
bld = unique(T.Bygningsnr);


% In current county, loop through all the data and put all the
% variables of one building in one row.
% initialize a table
TB = table;
TB.Geometry(1:length(bld))  = {'Point'};
fprintf('Bygninger med endring i fylke %02i : %i\n\t\t   Total Permits : %i\n',fylkenr(f),length(bld),height(T))
for b=1:length(bld)
    % find each unique numbered building.
    idb           = find(T.Bygningsnr==bld(b));
    Tsub                      = T(idb,:);
    Tsub                      = sortrows(Tsub,11);
    TB.Y(b)                   = max(abs(Tsub.Y)); % sometimes there are data missing (=0) this avboids using that
    TB.X(b)                   = max((Tsub.X)); % sometimes there are data missing (=0) this avboids using that
    TB.Bygningsnr(b)          = unique(Tsub.Bygningsnr);
    TB.Bygningtypekode(b)     = unique(Tsub.Bygningtypekode);
    %TB.Bygningstype(b)        = unique(Tsub.Bygningstype);
    TB.BruksarealTotatl(b)    = max(Tsub.BruksarealTotatl);
    TB.AntallBoenheter(b)     = max(Tsub.AntallBoenheter);
    TB.Actions(b)             = height(Tsub);
    TB.GjeldendeStatuskode(b) = unique(Tsub.GjeldendeStatuskode);
    
    TB.StartDEMO(b)           = early;
    TB.EndDEMO(b)             = late;
    TB.StartCONST(b)          = early;
    TB.EndCONST(b)            = late;
    statuser = unique(Tsub.BygningsstatuskodeSiden2009);
    for s=1:length(statuser)
        clear tdate
        statustime = unique(Str.Time((ismember(Str.Code,statuser(s)))));
        idx= find(ismember(Tsub.BygningsstatuskodeSiden2009,statuser(s)));
        for i=1:length(idx)
            try
                tdate(i) = datenum(Tsub.DATO(idx(i)),'dd.mm.yyyy');
            catch
                tdate(i) = datenum(Tsub.DATO(idx(i)));
            end
        end
        if statustime==1; TB.StartDEMO(b)  = max(TB.StartDEMO(b),max(tdate)) ;end
        if statustime==2; TB.EndDEMO(b)    = min(TB.EndDEMO(b),min(tdate))   ;end
        
        if statustime==3; TB.StartCONST(b) = max(TB.StartCONST(b),max(tdate));end
        if statustime==4; TB.EndCONST(b)   = min(TB.EndCONST(b),min(tdate))  ;end
    end
    
    TB.DEMOtidD(b)  = (TB.EndDEMO(b)-TB.StartDEMO(b));
    TB.CONSTtidD(b) = (TB.EndCONST(b)-TB.StartCONST(b));
    
    %if length(statuser)>3; TB(b,:); statuser; pause; end
    
    if rem(b,5000)==0; fprintf('Processed %7i of%7i permits\n',b,length(bld)); end
end

idx = find(TB.DEMOtidD==late);
TB.StartDEMO(idx) = NaN;
TB.EndDEMO(idx)   = NaN;
TB.DEMOtidD(idx)  = NaN;

idx = find(TB.CONSTtidD==late);
TB.StartCONST(idx) = NaN;
TB.EndCONST(idx)   = NaN;
TB.CONSTtidD(idx)  = NaN;



% find the open ended demolition projects:
idxO = find(TB.DEMOtidD>maxDEMOTime);

for i=1:length(idxO)
    if TB.StartDEMO(idxO(i)) == 0 % missing start time
        TB.StartDEMO(idxO(i)) = TB.EndDEMO(idxO(i))-meanDEMOtime;
        TB.DEMOtidD(idxO(i))  = meanDEMOtime;
    elseif TB.EndDEMO(idxO(i))> now % missing end time
        TB.EndDEMO(idxO(i)) = TB.StartDEMO(idxO(i))+meanDEMOtime;
        TB.DEMOtidD(idxO(i))  = meanDEMOtime;
    end
end

% find the open ended demolition projects:
idxO = find(TB.CONSTtidD>maxCONSTime);

for i=1:length(idxO)
    if TB.StartCONST(idxO(i)) == 0 % missing start time
        TB.StartCONST(idxO(i)) = TB.EndCONST(idxO(i))-meanCONSTtime;
        TB.CONSTtidD(idxO(i))  = meanCONSTtime;
    elseif TB.EndCONST(idxO(i))> now % missing end time
        TB.EndCONST(idxO(i)) = TB.StartCONST(idxO(i))+meanCONSTtime;
        TB.CONSTtidD(idxO(i))  = meanCONSTtime;
    end
end


bin1 = 0.15;
bin2 = 0.43;
bin3 = 0.42;

TB.DEMOmachineStart(:)  = NaN;
TB.DEMOmachineEnd(:)    = NaN;
TB.CONSTmachineStart(:) = NaN;
TB.CONSTmachineEnd(:)   = NaN;
for i=1:height(TB)
    TB.DEMOmachineStart(i)  = round(TB.StartDEMO(i)  + bin1*TB.DEMOtidD(i));
    TB.DEMOmachineEnd(i)    = round(TB.EndDEMO(i)    - bin3*TB.DEMOtidD(i));
    TB.CONSTmachineStart(i) = round(TB.StartCONST(i) + bin1*TB.CONSTtidD(i));
    TB.CONSTmachineEnd(i)   = round(TB.EndCONST(i)   - bin3*TB.CONSTtidD(i));
end



% Make struct of the table
Sout    = table2struct(TB);

end