function [TV,S] = EmSite_Station_Timevariation(S,HDDfile,VariableVacation_file,Emission_year)
% takes a matlab dateformatted array (uses start and end)
% and returns an Hourly emission function in the Hours in-between.
% Henrik Grythe -Dec.2017  -NILU, Kjeller
% Henrik Grythe -Aug.2020  -NILU, Kjeller
%--------------------------------------------------------------------------
utmTo = 33;
Htres = 10;

dn      = datenum([Emission_year,1,1,0,0,0]):1:datenum([Emission_year+1,1,0,0,0,0]);
stepOut = 1/24;
dnew    = min(dn):stepOut:max(dn)+1-stepOut;
dv      = datevec(dnew);
fprintf('First Hour starting: %s\n',datestr(min(dnew),'yyyy-mmm-dd HH:MM'))
fprintf('Last  Hour starting: %s\n',datestr(max(dnew),'yyyy-mmm-dd HH:MM'))
fprintf('Getting School and Bank Holidays for: %s\n',datestr(max(dnew),'yyyy'))
% Get CALENDAR with Holidays
% Calendar = Cabin_population(dn(1),Cabin_Population_file);
date     = mean(dn);
Calendar = Find_Norwegian_Holidays(date,VariableVacation_file);


% Adjusted Fit to working hours
daily_activity = [0.00,0.00,0.00,0.00,0.00,0.25,0.50,0.75,1.00,1.00,1.00,0.75,1.00,1.00,1.00,0.75,0.50,0.25,0.00,0.00,0.00,0.00,0.00,0.00,0.00];
daily_heating  = [0.70,0.70,0.70,0.70,0.70,0.75,0.75,0.75,1.00,1.00,1.00,0.95,1.00,1.00,1.00,0.75,0.75,0.75,0.70,0.70,0.70,0.70,0.70,0.70,0.70];
daily_dust     = [0.20,0.20,0.20,0.20,0.20,0.25,0.50,0.75,1.00,1.00,1.00,0.75,1.00,1.00,1.00,0.75,0.50,0.25,0.20,0.20,0.20,0.20,0.20,0.20,0.20];

% The weekday variation monday to sunday
weeks = [1,.5,.2];

% Calculate Daily Residential Weekday&HDD weight
dwAct = weeks(Calendar.Holiday+1);

%--------------------------------------------------------------------------
% Make a timevariation that corresponds with Residential and the two types
% of cabins for each station.
fprintf('Making Hourly Variations\n...\n')
Calendar.Time = datetime(datevec(Calendar.Mdate));
Ch            = table2timetable(Calendar);
TV            = retime(Ch,datetime(datevec(dnew)),'previous');
for i =1:length(dnew)
    date_vec = datevec(dnew(i));
    if dnew(i) < datenum([Emission_year 03 25 02 0 0]) || dnew(i)> datenum([Emission_year 10 25 02 0 0])
    % Use 1 for summer time
        zeroTO24 = 1;
    else 
    % Use 1 for summer time
        zeroTO24 = 2;        
    end
    
    if TV.Holiday(i) == 2
        act(i) = daily_activity(date_vec(4)+zeroTO24)*weeks(3);
        duh(i) = (2+daily_dust(date_vec(4)+zeroTO24))/4;
        dhe(i) = (2+daily_heating(date_vec(4)+zeroTO24))/4;
    end
    
    if TV.Weekday(i)==6 || TV.Holiday(i) == 1
        act(i) = daily_activity(date_vec(4)+zeroTO24)*weeks(2);        
        duh(i) = (1+daily_dust(date_vec(4)+zeroTO24))/3;
        dhe(i) = (1+daily_heating(date_vec(4)+zeroTO24))/3;
    end
    
    if TV.Holiday(i) < 1 && TV.Weekday(i) < 6 
        act(i) = daily_activity(date_vec(4)+zeroTO24)*weeks(1);                
        duh(i) = daily_dust(date_vec(4)+zeroTO24);
        dhe(i) = daily_heating(date_vec(4)+zeroTO24);
    end
end
TV.Activity    = act';
TV.HourDust    = duh';
TV.HourHeating = dhe';
end






