% get a fresh start:
clear all; close all; clc
%--------------------------------------------------------------------------
diary Emsite_runfile.out

global ipath tpath opname ofilename
global outgridsize numPartsSSBOutFile
global printsplit Emission_year BuildDemo difficulty_amplifier
global HDDfile VariableVacation_file Phase_duration Building_phases
global Tloes Tgc Tsilt Htres
global Anleggsdiesel_weight Tools_wight Heating_wight
global LargeMachines_kWhm2 SmallMachines_kWhm2 HeatMachines_kWhm2
global EF_TSP EF_PM10 EF_PM25 SSBgridFile comps
global Fuelsplit_Large Fuelsplit_Small Fuelsplit_Heat Fuelsplit_Name EF_L_yr EF_S_yr EF_H_yr EF_G_yr EF_P_yr
global typer Str KMNEfilename

%--------------------------------------------------------------------------
% M O D E L   O P T I O N S
%--------------------------------------------------------------------------
Emission_year = 2019;
% BuildDemo = 'CONST'; % 2010 2011 2012 2013 2014 2015 2016 2017 2018 2019 2020
BuildDemo = 'DEMO';  % 2010 2011 2012 2013 2014 2015 2016 2017 2018 2019 2020
% BuildDemo = 'ROAD';
% BuildDemo = 'TV';
%--------------------------------------------------------------------------
%--------------------------------------------------------------------------

% Toggle Linux/Windows path
if ispc
    bp = 'N:\Inby\Aktive-prosjekter\o120107_EmSite\';
    pth = 'N:\Inby\';
    addpath N:\Inby\Users\heg\MatLab\Tools
else
    bp =  '/storage/nilu/Inby/Aktive-prosjekter/o120107_EmSite/';
    pth = '/storage/nilu/Inby/';
    addpath /storage/nilu/Inby/Users/heg/MatLab/Tools
end

%--------------------------------------------------------------------------
% BASIC pathnames
opname   = sprintf('%s%s',bp,'EmSite_Model/Output/');
ipath    = sprintf('%s%s',bp,'EmSite_Model/Input/');
tpath    = sprintf('%s%s',bp,'EmSite_Model/Temp/');

% Input files
VariableVacation_file = sprintf('%s%s',ipath,'VariableVacationWeeks.xlsx');
BygningTypeFil        = sprintf('%s%s',ipath,'MatrikkelLookupStrings.xlsx');
BygningTypeSheet      = 'Bygningstype_complete';
lookupsheet           = 'MatrikkelChanges';
HDDfile               = sprintf('%s%s',ipath,'MET/Station_Temp_2005-2019_eKlima.xlsx');
soilfile              = sprintf('%s%s',ipath,'Soil/LosmasseFlate_20210510');
ExhaustEF_File        = sprintf('%s%s',ipath,'Exhaust_EF.xlsx');
KMNEfilename          = sprintf('%s%s',ipath,'KMN/Kommuner2020');
%--------------------------------------------------------------------------
% M O D E L   O P T I O N S
%--------------------------------------------------------------------------
% toggle on (=1) TO:
% convert the shape files from UTM 32 tio UTM 33
makeplot             = 0;   % some plots to view after the model has run
convertUTM           = 1;   %
outgridsize          = 250; % available options are 250 and 500
do_month             = 0;   % makes mothly activity files as additional output
difficulty_amplifier = 1.5; % Energy increase as a result of difficult ground conditions.
LargeMachines_kWhm2  = 30;  % Basic assumption for LNRMM
SmallMachines_kWhm2  = 2.53;   % Basic assumption for SNRMM
HeatMachines_kWhm2   = 47;  % Basic assumption for Heat demand
Htres                = 5;   % Basic assumption for Heat threshold

% Set some enterpretation stuff, counties and string match:
printsplit = '--------------------------------\n';

% Counties of norway number and name
fylkenr = [3 11 15 18 30 34 38 42 46 50 54];
fylke_Str = [{'Oslo'},{'Rogaland'},{'Moere og Romsdal'},{'Nordland'},{'Viken'},...
    {'Innlandet'},{'Vestfold og Telemark'},{'Agder'},{'Vestland'},{'Troendelag'},...
    {'Troms-Finnmark'}];
months = [{'Jan'},{'Feb'},{'Mar'},{'Apr'},{'Mai'},{'Jun'},{'Jul'},{'Aug'},{'Sep'},{'Okt'},{'Nov'},{'Dec'}];

% parameters for timesteps in CONSTRUCTION process
ConstrPhase = [{'PreMachines'},{'GR'},{'FU'},{'CB'},{'TB'},{'FI'}];
ConstrDates = [{'Legalized Start'},{'Start Groundwork'},{'Start Foundation'},...
    {'Start top Construction'},{'Closed Building'},{'Usage Legalized'}];
ConstrDates = [{'Godkjenning'},{'Start Grunnarbeid'},{'Start Fundament'},...
    {'Start Bygg'},{'Tett Bygning'},{'I bruk tillatelse'}];

% each phase of building and its duration (%)
Building_phases      = [1   ,2   , 3  ];
Phase_duration       = [0.3, 0.3 , 0.4];
% Parameters for assigning the fuel use in different building periods
Anleggsdiesel_weight = [0.0, 0.0, 0.6 ,0.3 , 0.1 ,0.0];
Heating_wight        = [0.0, 0.0, 0.0 ,0.3 , 0.6 ,0.1];
Tools_wight          = [0.0, 0.0, 0.1 ,0.3 , 0.5 ,0.2];

%--------------------------------------------------------------------------
% R E A D   D E F I N I T I O N  T A B L E S
%--------------------------------------------------------------------------
fprintf('Read Definitions tables \n')
typer    = readtable(BygningTypeFil,'Sheet',BygningTypeSheet);
Str      = readtable(BygningTypeFil,'Sheet',lookupsheet);
Tloes    = readtable(sprintf('%s%s',ipath,'Soil/losmasser_code.xlsx'),'Sheet','Loesmasse');
Tsilt    = readtable(sprintf('%s%s',ipath,'Soil/losmasser_code.xlsx'),'Sheet','Silt_ID');
Tgc      = readtable(sprintf('%s%s',ipath,'Soil/losmasser_code.xlsx'),'Sheet','GC');

% Read the emission factors per kWh for exhaust.
fprintf('Read Exhaust EF files\n')
EF_L    = readtable(ExhaustEF_File,'Sheet','LNRMM');
EF_S    = readtable(ExhaustEF_File,'Sheet','SNRMM');
EF_H    = readtable(ExhaustEF_File,'Sheet','HG');
EF_G    = readtable(ExhaustEF_File,'Sheet','LPG');
EF_P    = readtable(ExhaustEF_File,'Sheet','Petrol');

% This years Emission factors
EF_L_yr = EF_L(EF_L.Year == Emission_year,:);
EF_S_yr = EF_S(EF_S.Year == Emission_year,:);
EF_H_yr = EF_H(EF_H.Year == Emission_year,:);
EF_G_yr = EF_G(EF_G.Year == Emission_year,:);
EF_P_yr = EF_G(EF_P.Year == Emission_year,:);


comps = [{'NOx'}, {'VOC'}, {'CH4'}, {'CO'}, {'N2O'}, {'NH3'}, {'PM'}, {'PM10'}, {'PM2_5'}, {'BC'}, {'FC'}, {'CO2'}];
Fuelsplit_Name       = [{'Anleggsdiesel'},{'Bensin'},{'LPG'}];
Fuelsplit_Large      = [1.0, 0.0, 0.0];
Fuelsplit_Small      = [0.9, 0.1, 0.0];
Fuelsplit_Heat       = [0.8, 0.0, 0.2];

BaseFields   = [{'Geometry'},{'BoundingBox'},{'X'},{'Y'},{'SSBID'},{'KommuneNR'}];
EnergyFields = [{'Anleggsdiesel'},{'Bensin'},{'LPG'},{'LNRMM'},{'SNRMM'}];



% Emission factors for non-exhaust
TneEF    = readtable(sprintf('%s%s',bp,'Data/EF/EF_building_construction.xlsx'),'Sheet','NON-EXHAUST');
TneEFt   = readtable(sprintf('%s%s',bp,'Data/EF/EF_building_construction.xlsx'),'Sheet','Readme');
for i =1:height(TneEF)
    name = char(TneEF.Var1(i));
    switch name
        case 'PM2.5'
            EF_PM25(TneEF.Type_Construction(i)) = TneEF.EF(i);
        case 'PM10'
            EF_PM10(TneEF.Type_Construction(i)) = TneEF.EF(i);
        case 'TSP'
            EF_TSP(TneEF.Type_Construction(i)) = TneEF.EF(i);
        otherwise
            fprintf('No EMission fit for \n')
            TneEF(:,i)
    end
end


if outgridsize == 500
    SSBgridFile = sprintf('%sEmission_Group/Ancillary_Data/Norway/NO_Shapes/SSB_Grid/Rute_500m_Norge/ruter500m_Norge',pth);
    fprintf('Reading SSB grid output file\n')
elseif outgridsize == 250
    SSBgridFile = sprintf('%sEmission_Group/Ancillary_Data/Norway/NO_Shapes/SSB_Grid/Rute_250m_Norge/Rute_250m_Norge',pth);
    numPartsSSBOutFile = 7;
    % NOTgridFile = '/storage/nilu/Inby/Emission_Group/Ancillary_Data/Norway/NO_Shapes/Norway_Administrative_Borders/Landsdel_NO';
end


fprintf('E M S I T E   R U N N I N G \n')
fprintf(printsplit)
fprintf('YEAR  : %i \n',Emission_year)
fprintf('TYPE  : %s \n',BuildDemo)
fprintf(printsplit)


%----------------------------------------------------------------------
%  ADD HERE AN OVERVIEW OF PARAMETERS, FILES AND SETTINGS TO BE WRITTEN TO
%  FILE
%----------------------------------------------------------------------




%----------------------------------------------------------------------
%  P R E P R O C E S S  O P T I O N S
%----------------------------------------------------------------------
do_preprocess   = 0;
add_kommune     = 1; % add kommunenummer to buildings (with a valid position)
use_FKBlocation = 1; % add location where possible to the building that has missing x or y in Matrikkel data
use_KVlocation  = 1; % add location where possible to the building that has missing x or y in Matrikkel data
add_soil        = 1; % combine the soil layer with the building data

% set the base name for the output file:
ofilename = sprintf('%s%s',opname,'Bygninger_');
if add_soil;        ofilename = strcat(ofilename,'Soil_');  end
if convertUTM;      ofilename = strcat(ofilename,'UTM33_'); end
if use_FKBlocation; ofilename = strcat(ofilename,'FKB_');   end
if use_KVlocation;  ofilename = strcat(ofilename,'KV_');    end
fprintf('OUTFILENAME = \n%s\n',ofilename)

%**************************************************************************
% B E G I N   P R E P R O C E S S
%**************************************************************************
% global do_preprocess add_kommune use_FKBlocation use_KVlocation add_soil
% global printsplit convertUTM
% global soilfile bp ipath f fylkenr Str
if do_preprocess
    fprintf(printsplit)
    fprintf('B E G I N   P R E P R O C E S S \n')
    fprintf(printsplit)
    % if add Soil, load data from NGU (UTM33)
    if add_soil
        fprintf('Reading Soil information...  ')
        Dirt = shaperead(soilfile);
        fprintf('Done\n')
        % find centroid
        for i=1:length(Dirt)
            xpos = extractfield(Dirt(i),'X');
            ypos = extractfield(Dirt(i),'Y');
            Xmid(i) = nanmean(xpos);
            Ymid(i) = nanmean(ypos);
            Diam(i) = nanmax(sqrt( (xpos-Xmid(i)).^2 + (ypos-Ymid(i)).^2));
        end
    end
    
    %----------------------------------------------------------------------
    % M A K E   F Y L K E   F I L E S
    %----------------------------------------------------------------------
    % loop through each county (fylkenr)
    for f = 1:length(fylkenr)
        % Read the original file and fix some norwegian carachter bugs
        fname     = sprintf('Bygningsdata_fylke_%02i',fylkenr(f));
        filename  = sprintf('%sKV_BLD/%s.xlsx',ipath,fname);
        [TB,Sout] = EmSite_Geoprocess_KV_ActiveBuilds(filename,f,fylkenr,Str);
        
        if convertUTM % assumes a conversion from 32 to 33
            if fylkenr(f) == 18
                utmFrom = 33;
            elseif fylkenr(f) == 54
                % Finnmark has utm 35 and Troms has UTM 33: Need to find a way
                % to separate them.
                utmFrom = 33;
            else
                utmFrom = 32;
                Sout    = utm2utm(Sout,utmFrom,33);
            end
            
            TB        = struct2table(Sout);
        end
        %----------------------------------------------------------------------
        % F I L L   M I S S I N G   L O C A T I O N S
        %----------------------------------------------------------------------
        if use_FKBlocation
            filename = sprintf('%s%s%02i',ipath,'FKB_BLD/FKB_Bygning_Points_fylke_',fylkenr(f));
            [TB,Sout] = EmSite_Geoprocess_Add_Location_from_FKB(filename,TB);
        end
        
        if use_KVlocation
            filename = sprintf('%s%s%02i',ipath,'MAT_BLD/MatrikkelenBygning_fylke_',fylkenr(f));
            [TB,Sout] = EmSite_Geoprocess_Add_Location_from_KV(filename,TB);
        end
        
        %----------------------------------------------------------------------
        % A D D   M U N I C I P A L I T Y
        %----------------------------------------------------------------------
        if add_kommune
            filename = sprintf('%s%s',ipath,'KMN/Kommuner2020');
            [TB,Sout] = EmSite_Geoprocess_Add_KV_Municipality(filename,Sout);
        end
        
        %----------------------------------------------------------------------
        % S O I L   P A R A M E T E R S
        %----------------------------------------------------------------------
        if add_soil
            [TB,Sout] = EmSite_Geoprocess_Add_NGI_Soil(Dirt,Sout,Xmid,Ymid,Diam);
        end
        
        OUTfile   = strcat(ofilename,sprintf('fylke_%02i.xlsx',fylkenr(f)));
        DEMOfile  = strcat(ofilename,sprintf('fylke_%02iDEMO.xlsx',fylkenr(f)));
        CONSTfile = strcat(ofilename,sprintf('fylke_%02iCONST.xlsx',fylkenr(f)));    %
        
        % Write tables
        fprintf('Writing files :\n%s\n...\n',strcat(ofilename,sprintf('fylke_%02i',fylkenr(f))))
        writetable(TB,OUTfile)
        
        TDEMO  = TB(~isnan(TB.DEMOtidD),:);
        writetable(TDEMO,DEMOfile)
        fprintf('Of the %i Enties %i (%4.1f%%)were DEMOLITION\n',height(TB),height(TDEMO),100*height(TDEMO)/height(TB))
        
        TCONST = TB(~isnan(TB.CONSTtidD),:);
        writetable(TCONST,CONSTfile)
        fprintf('Of the %i Enties %i (%4.1f%%)were CONSTRUCTION\n',height(TB),height(TCONST),100*height(TCONST)/height(TB))
    end
    
    
    %----------------------------------------------------------------------
    % M A K E   A N N U A L   F I L E S
    %----------------------------------------------------------------------
    Tbs = table; Tbe = table; Ttemp = table;
    k = 1;
    for y = 2010:2020
        fprintf('%04i: ',y)
        Ys = datenum([y 01 01 0 0 0]);
        Ye = datenum([y+1 01 01 0 0 0]);
        TcY = table;
        for f = 1:length(fylkenr)
            fprintf('%02i, ',fylkenr(f))
            fileINc = strcat(ofilename,sprintf('fylke_%02iCONST.xlsx',fylkenr(f)));
            Tc = readtable(fileINc);
            ic = contains(Tc.Properties.VariableNames,'DEMO');
            Tc =Tc(:,~ic);
            
            Tc.Fylke(:) = fylkenr(f);
            % all entries wich started after the end of year
            ic1 = Tc.StartCONST > Ye;
            % all entries wich ended before the start of year
            ic2 = Tc.EndCONST   < Ys;
            ic = ~ic1 & ~ic2;
            TcY = [TcY;Tc(ic,:)];
         end
        fprintf('\n')
        
        %----------------------------------------------------------------------
        % This section finds the corresponding field in the met file
        Sout = table2struct(TcY);
        MetX = zeros(size(Sout));
        MetY = zeros(size(Sout));
        fprintf('****\n\tFinding METEOROLGY FIELD CONS\n')
        for b = 1:length(Sout)
            [Met] = EmSite_Calc_FindMetField(Sout(b),ipath);
            MetX(b) = Met.FieldXY(1);
            MetY(b) = Met.FieldXY(2);
            if rem(b,5000)==0; fprintf('Processed %7i of%7i buildings\n',b,length(Sout)); end
        end
        %TB = struct2table(Sout);
        TcY.MetX = MetX;
        TcY.MetY = MetY;
        Sout = table2struct(TcY);
        
        
        writetable(TcY,strcat(ofilename,sprintf('%04iCONST.xlsx',y)))
        
 
    end
    
    % make annual statistics
    Tbs = table; Tbe = table; Ttemp = table; Ttot = table; k = 1 ;
    for y = 2010:2020
        % Buildings started
        TcY = readtable(strcat(ofilename,sprintf('%04iCONST.xlsx',y)));
        cy  = datevec(TcY.StartCONST);
        fprintf('%i\n',y)
        for f = 1:length(fylkenr)
            for t = 1:height(typer)
                cnt = cy(:,1)==y & TcY.Fylke == fylkenr(f) & TcY.Bygningtypekode==typer.Bygningstypekode(t);
                Ttemp.Year         = y;
                Ttemp.Bygningstype = typer.Bygningstypekode(t);
                Ttemp.Fylke        = fylkenr(f);
                Ttemp.Antall       = sum(cnt);
                Ttemp.Antallm2     = nansum(TcY.BruksarealTotatl(cnt));
                Tbs = [Tbs;Ttemp];
                
            end
        end
        Ttot.Year(k)            = y;
        idx = find(Tbs.Year == y);
        Ttot.AntallStarted(k)   = nansum(Tbs.Antall(idx));
        Ttot.Antallm2Started(k) = nansum(Tbs.Antallm2(idx));
        
        % fprintf('Started in %i, \n',y,sum(Tbs.))
        % Buildings Finished
        cye  = datevec(TcY.EndCONST);
        for f = 1:length(fylkenr)
            for t = 1:height(typer)
                cnte = cye(:,1)==y & TcY.Fylke == fylkenr(f) & TcY.Bygningtypekode==typer.Bygningstypekode(t);
                Ttemp.Year         = y;
                Ttemp.Bygningstype = typer.Bygningstypekode(t);
                Ttemp.Fylke        = fylkenr(f);
                Ttemp.Antall       = sum(cnte);
                Ttemp.Antallm2     = nansum(TcY.BruksarealTotatl(cnte));
                Tbe = [Tbe;Ttemp];
            end
            
        end
        idx = find(Tbe.Year == y);
        Ttot.AntallEnded(k)   = nansum(Tbe.Antall(idx));
        Ttot.Antallm2Ended(k) = nansum(Tbe.Antallm2(idx));
        k = k+1;
    end

    filen = sprintf('%s%s.xlsx',opname,'PivotStatistics_BuildYear');
    writetable(Tbs,filen,'Sheet','ConstructionStarted')
    writetable(Tbe,filen,'Sheet','ConstructionEnded')       
    writetable(Ttot,filen,'Sheet','NationalAnnual')       
        
    %----------------------------------------------------------------------
    Ttemp = table;
   for y = 2010:2020
        fprintf('%04i: ',y)
        Ys = datenum([y 01 01 0 0 0]);
        Ye = datenum([y+1 01 01 0 0 0]);        TdY = table;
        for f = 1:length(fylkenr)
            fprintf('%02i, ',fylkenr(f))
            fileINd = strcat(ofilename,sprintf('fylke_%02iDEMO.xlsx',fylkenr(f)));
            Td = readtable(fileINd);
            id = contains(Td.Properties.VariableNames,'CONS');
            Td =Td(:,~id);
            
            Td.Fylke(:) = fylkenr(f);
            % all entries wich started after the end of year
            id1 = Td.StartDEMO > Ye;
            % all entries wich ended before the start of year
            id2 = Td.EndDEMO   < Ys;
            id = ~id1 & ~id2;
            TdY = [TdY;Td(id,:)];
         end
        fprintf('\n')

        
        % This section finds the corresponding field in the met file
        Sout = table2struct(TdY);
        MetX = zeros(size(Sout));
        MetY = zeros(size(Sout));
        fprintf('****\n\tFinding METEOROLGY FIELD DEMO \n')
        for b = 1:length(Sout)
            [Met] = EmSite_Calc_FindMetField(Sout(b),ipath);
            MetX(b) = Met.FieldXY(1);
            MetY(b) = Met.FieldXY(2);
            if rem(b,5000)==0; fprintf('Processed %7i of%7i buildings\n',b,length(Sout)); end
        end
        %TB = struct2table(Sout);
        TdY.MetX = MetX;
        TdY.MetY = MetY;
        SoutD = table2struct(TdY);
                
        writetable(TdY,strcat(ofilename,sprintf('%02iDEMO.xlsx',y)))     
    end
    
    
    %----------------------------------------------------------------------
    % P R E P R O C E S S   M E T E O R O L G Y   F O R   D U S T   T V
    %----------------------------------------------------------------------
    %     for y = 2010:2020
    %
    %         % Write NetCdf for DEM
    %         % /storage/nilu/Inby/Aktive-prosjekter/o120107_EmSite/EmSite_Model/Input/BaseGrid.nc
    %
    %
    %     end
    
else
    fprintf(printsplit)
    fprintf('\n S K I P P I N G    P R E P R O C E S S \n \n')
    fprintf(printsplit)
end

%**************************************************************************
% A N N U A L   D A T A   D E M O L I T I O N
%**************************************************************************
[SDEMO] =  EmSite_DEMOLITION();

%**************************************************************************
% A N N U A L   D A T A   C O N S T R U C T I O N
%**************************************************************************
[SCONS] =  EmSite_CONSTRUCTION();

%**************************************************************************
% A N N U A L   B U I L D I N G   R O A D S
%**************************************************************************
% [SCONS] =  EmSite_ROADS();


%**************************************************************************
% T I M  E V A R I A T I O N
%**************************************************************************

Stv = [];
[TV,Stv] = EmSite_Station_Timevariation(Stv,HDDfile,VariableVacation_file,Emission_year);
mTV = retime(TV,'monthly','mean');
dTV = retime(TV,'daily','mean');

ncfile   = sprintf('%sMET/DEM_%04i.nc',ipath,Emission_year);
DEM      = ncread(ncfile,'DEM');
fprintf('Read from file dust emission potential %i\n',Emission_year)

% %%% All of norway average
% gDEM = squeeze(sum(DEM,3));
% gDEM(gDEM >=365)=NaN;
%
% for i = 1:size(gDEM,1)
%     for j = 1:size(gDEM,2)
%         if isnan(gDEM(i,j))
%             DEM(i,j,:) = NaN;
%         end
%     end
% end
% nDEM = squeeze(nanmean(nanmean(DEM)))

% %%% Main city average
nDEM = (squeeze(DEM(100,1200,:))+ squeeze(DEM(50,1350,:))+ squeeze(DEM(1100,100,:))+ squeeze(DEM(350,1350,:)))/4; clear DEM

[Met]          = EmSite_Calc_MetHDD(Emission_year,ipath,Htres);
HDD = Met.HDD; clear Met
nHDD = (squeeze(HDD(100,1200,:))+ squeeze(HDD(50,1350,:))+ squeeze(HDD(1100,100,:))+ squeeze(HDD(350,1350,:)))/4; clear HDD
fprintf('Calculated HDD %i\n',Emission_year)

dTV.DEM_Norway = nDEM(1:height(dTV));
dTV.HDD_Norway = nHDD(1:height(dTV));

oTV            = retime(dTV,TV.Time,'previous');
oTV.Date       = datestr(TV.Time,'dd.mm.yyyy');
oTV.Hour       = datestr(TV.Time,'HH:MM');
oTV.Activity   = TV.Activity/sum(TV.Activity);
oTV.DEM_Norway = oTV.DEM_Norway/sum(oTV.DEM_Norway);
oTV.HDD_Norway = oTV.HDD_Norway/sum(oTV.HDD_Norway);
writetimetable(oTV,sprintf('%s%i_TimeVariation_Norway.xlsx',opname,Emission_year))

%**************************************************************************
% E N D  P R O G R A M
%**************************************************************************


if makeplot
    
    figure;clf
    subplot(3,2,[1,2])
    plot(dTV.Time,dTV.Activity,'r','LineWidth',3)
    hold on
    plot(mTV.Time,mTV.Activity,'k','LineWidth',3)
    % datetick('x','keepticks')
    title('Activity Level')
    
    subplot(3,2,[3,4])
    plot(TV.Time(1:7*24),TV.Activity(1:7*24),'r','LineWidth',3)
    hold on
    plot(TV.Time(1:7*24),TV.Activity(1:7*24),'k','LineWidth',3)
    % datetick('x','ddd','keepticks')
    title('Activity Level')
    
    subplot(3,2,[5,6])
    plot(dTV.Time,dTV.Activity,'r','LineWidth',3)
    hold on
    plot(dTV.Time,dTV.Activity,'ko','LineWidth',3)
    % datetick('x','ddd','keepticks')
    title('Activity Level')
    
    
    
    du = squeeze(nanmean(nanmean(DEM)));
    x = linspace(1,12,length(du));
    gDEM = squeeze(sum(DEM,3));
    gDEM(gDEM >=365)=NaN;
    
    
    f = figure(2); clf;
    subplot(3,2,[1:4])
    im = imagesc(gDEM')
    colormap( [1 1 1; bone(256)])
    % pcolor(gDEM)
    % set(im, 'AlphaData', ~isnan(gDEM))
    colorbar
    fname = sprintf('Annual days with dust emission potential %i',Emission_year);
    title(fname)
    hold on
    box on
    %     scatter(100,1200,'k','filled')
    %     scatter(50,1350,'w','filled')
    %     scatter(1100,100,'y','filled')
    %     scatter(350,1350,'r','filled')
    set(gca,'XTickLabel','','YTickLabel','')
    %figure(1); clf;
    x = datenum([Emission_year,1,1,0,0,0]):1:datenum([Emission_year+1,1,1,0,0,0]);
    subplot(3,2,[5:6])
    %    title('Daily dust emission potential (dryness)')
    
    bh = area(x,squeeze(DEM(100,1200,:)));
    bh.FaceAlpha = .1;bh.EdgeColor = bh.FaceColor;bh.LineWidth = 2;
    hold on
    
    bh = area(x,squeeze(DEM(50,1350,:)));
    bh.FaceAlpha = .1;bh.EdgeColor = bh.FaceColor;bh.LineWidth = 2;
    
    bh = area(x,squeeze(DEM(1100,100,:)));
    bh.FaceAlpha = .1;bh.EdgeColor = bh.FaceColor;bh.LineWidth = 2;
    
    bh = area(x,squeeze(DEM(350,1350,:)));
    bh.FaceAlpha = .1;bh.EdgeColor = bh.FaceColor;bh.LineWidth = 2;
    
    plot(x,(squeeze(DEM(100,1200,:))+ squeeze(DEM(50,1350,:))+ squeeze(DEM(1100,100,:))+ squeeze(DEM(350,1350,:)))/4,'k','LineWidth',3)
    
    
    
    legend('West','Oslo','South','North','Norway')
    xlim([min(x) max(x)])
    datetick('x','keepticks')
    ylabel('Daily dust Emission Potential')
    
    
    
    
    
    %     plot(sum(HTE,1)/2,'LineWidth',2)
    %     hold on
    %     plot(nansum(HME,1),'LineWidth',2)
    %     plot(sum(SME,1),'LineWidth',2)
    %     plot(x,du*mean(nansum(HME,1)))
    %     ylabel('kWh')
    %     set(gca,'XTick',1:12,'XTickLabel',months)
    %     title(sprintf('%i Monthly Energy demand in Construction of buildings',Emission_year))
    %     legend('Heating','Large Machines','Small Machines')
    %     grid on; box on
    
    %scatter(extractfield(Sout,'BruksarealTotatl'),sum(HTE,2))
    %
    %     bh = bar(squeeze(DEM(100,1400,:)));
    %     bh.FaceAlpha = .2;
    %     hold on
    %     bh = bar(squeeze(DEM(400,1400,:)));
    %     bh.FaceAlpha = .2;
    %     bh = bar(squeeze(DEM(800,200,:)));
    %     bh.FaceAlpha = .2;
    %     legend('West','Oslo','North')
end

diary off

